@@ -2,14 +2,10 @@
 import os
 import uuid
 import copy
-import signal
 import logging
+import inspect
 from flask import Flask
 from jinja2 import BaseLoader
-try:
-    from setproctitle import setproctitle
-except ImportError:
-    setproctitle = None
 
 from .view import BaseWebView
 
@@ -18,13 +14,14 @@ __all__ = []
 
 class SimpleWebServer(object):
 
-    def __init__(self, name, options={}, logger=None, reqlogger=None):
+    def __init__(self, name, proctitle='', options={}, logger=None,
+                 reqlogger=None, debug=0):
         # web server name
         self.name = name
         # process title to show in os process table
-        self.proctitle = self.name
+        self.proctitle = proctitle or name
         # debug mode
-        self.debug = 0
+        self.debug = debug
 
         # web server config options
         self.options = copy.deepcopy(options)
@@ -57,10 +54,16 @@ class SimpleWebServer(object):
             self.app = self.create_app()
 
     def add_view(self, view_hnd):
-        if not isinstance(view_hnd, BaseWebView):
+        if inspect.isclass(view_hnd) and issubclass(view_hnd, BaseWebView):
+            view_hnd = view_hnd()
+        elif not isinstance(view_hnd, BaseWebView):
             raise RuntimeError("INVALID_VIEW - %s" % view_hnd)
 
         view_hnd.parent = self
+        if not view_hnd.log:
+            view_hnd.log = self.log
+        if not view_hnd.debug:
+            view_hnd.debug = self.debug
         view_hnd.initialize()
         for url, endpoint in view_hnd.routes:
             self.app.add_url_rule(
@@ -98,10 +101,10 @@ class SimpleWebServer(object):
         @app.errorhandler(Exception)
         def exception_handler(e):
             if hasattr(e, 'name') and hasattr(e, 'code'):
-                return e.name, e.code
+                return str(e.name).upper(), e.code
             else:
-                self.log.error(str(e), exc_info=bool(self.bebug))
-                return "Internal Server Error", 500
+                self.log.error(str(e), exc_info=bool(self.debug))
+                return "INTERNAL SERVER ERROR", 500
 
         return app
 
@@ -110,17 +113,23 @@ class SimpleWebServer(object):
         if self.reqlog:
             logging.getLogger('werkzeug').parent = self.reqlog
 
-        # process PID
-        self.root_pid = os.getpid()
+        # store root process PID
+        self.app.config['ROOT_PID'] = os.getpid()
 
         # set daemon process title
         if self.proctitle:
-            if setproctitle:
+            try:
+                from setproctitle import setproctitle
                 setproctitle(str(self.proctitle).strip().lower())
-            else:
-                self.log.debug("ignoring setproctitle - not installed")
+            except ImportError:
+                self.log.debug("ignoring setting proctitle")
 
         self.app.run(host=host, port=port, **kwargs)
 
     def stop(self):
-        os.kill(self.root_pid, signal.SIGTERM)
+        import signal
+
+        pid = self.app.config.get('ROOT_PID')
+        if pid:
+            self.log.info("stop request")
+            os.kill(pid, signal.SIGTERM)
