@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import logging
 from flask import request
 
 __all__ = []
@@ -11,7 +10,7 @@ class BaseWebView(object):
     # allowed methods for view
     methods = ['GET', 'POST']
 
-    def __init__(self, name=None, logger=None):
+    def __init__(self, name=None, logger=None, debug=0):
         # view name
         self.name = name if name else self.__class__.__name__
         # view parent handler
@@ -19,40 +18,37 @@ class BaseWebView(object):
         # view logger
         self.log = logger
         # debug mode
-        self.debug = 0
+        self.debug = debug
 
     def initialize(self):
-        if not self.parent:
-            raise RuntimeError(
-                "INVALID_PARAMS - no parent handler defined")
+        pass
 
-        if not self.log:
-            self.log = logging.getLogger(self.name)
-            self.log.parent = self.parent.log
-            self.log.level = self.parent.log.level
-        if not self.debug and self.log.level == logging.DEBUG:
-            self.debug = 1
+    # check xhr/ajax request type
+    @classmethod
+    def is_xhrequest(cls):
+        request_xhr = request.headers.get('X-Requested-With')
+        if request_xhr and request_xhr == 'XMLHttpRequest':
+            return True
+        return False
 
-        self.log.debug("initializing")
-
-    def dispatch_request(self, *args, **kwargs):
+    def dispatch_request(self, **kwargs):
         # exec before request handlers
         if hasattr(self, 'before_request'):
-            response = self.before_request(*args, **kwargs)
+            response = self.before_request(**kwargs)
             if response is not None:
                 return response
 
         # dispatch request
-        response = self.handle_request(
-            request.method.lower(), *args, **kwargs)
+        response = self.handle_request(**kwargs)
 
         # exec after request handlers
         if hasattr(self, 'after_request'):
-            return self.after_request(response, *args, **kwargs)
+            return self.after_request(response, **kwargs)
 
         return response
 
-    def handle_request(self, method, *args, **kwargs):
+    def handle_request(self, **kwargs):
+        method = request.method.lower()
         if not hasattr(self, method):
             # use GET method instead of HEAD if not implemented
             if method == 'head' and hasattr(self, 'get'):
@@ -60,19 +56,19 @@ class BaseWebView(object):
             else:
                 return "Method Not Allowed", 405
 
-        return getattr(self, method)(*args, **kwargs)
+        return getattr(self, method)(**kwargs)
 
-    # def before_request(self, *args, **kwargs):
+    # def before_request(self, **kwargs):
     #     return None
 
-    # def after_request(self, response, *args, **kwargs):
+    # def after_request(self, response, **kwargs):
     #     return response
 
-    # def head(self, *args, **kwargs):
+    # def head(self, **kwargs):
     #     raise NotImplementedError()
 
-    # def get(self, *args, **kwargs):
+    # def get(self, **kwargs):
     #     raise NotImplementedError()
 
-    # def post(self, *args, **kwargs):
+    # def post(self, **kwargs):
     #     raise NotImplementedError()
